@@ -8,8 +8,10 @@
 int main(int argc, char *argv[])
 {
     QApplication a(argc, argv);
-    QCoreApplication::setOrganizationName("Stephen Lacey");
-    QCoreApplication::setApplicationName("Sit Rep");
+    QCoreApplication::setOrganizationName("Shep");
+    QCoreApplication::setOrganizationDomain("maemo.org");
+    QCoreApplication::setApplicationName("sitrep");
+
     MainWindow w;
     w.show();
     return a.exec();
